@@ -4,15 +4,18 @@
  * Author          : Ulrich Pfeifer
  * Created On      : Fri Nov 10 15:35:13 1995
  * Last Modified By: Ulrich Pfeifer
- * Last Modified On: Fri Nov 10 15:40:19 1995
+ * Last Modified On: Tue Nov 14 15:54:20 1995
  * Language        : C
- * Update Count    : 4
+ * Update Count    : 7
  * Status          : Unknown, Use with caution!
  * 
  * (C) Copyright 1995, Universitt Dortmund, all rights reserved.
  * 
  * $Locker: pfeifer $
  * $Log: dictionary.h,v $
+ * Revision 2.0.1.2  1995/11/16  12:23:55  pfeifer
+ * patch11: Added document.
+ *
  * Revision 2.0.1.1  1995/11/10  14:52:51  pfeifer
  * patch9: Extern definitions.
  *
@@ -35,4 +38,5 @@ extern int find_word _AP((char *database_name, char *field_name, char *word,
 extern int postings _AP((char *database_name, char *field_name, char *word, 
                        long *number_of_postings));
 extern char *headline _AP((char *database_name, long docid));
+extern char *document _AP((char *database_name, long docid));
 #endif
